// Compile:
// > gcc sq3_parse.cpp -o sq3_parse -lsqlite3
//
// Run:
// > ./sq3_parse spectrum.grid.sq3
//

#include <stdio.h>
#include <sqlite3.h>
#include <string.h>

static int callback1(void *NotUsed, int argc, char **argv, char **azColName){
  int i;

  /*
  for(i=0; i<argc; i++)
    printf("%s,", azColName[i]);
  printf("\n");
  */

  for(i=0; i<argc; i++){
    if (strcmp("FFTNum",azColName[i]) == 0)
      continue;

    if (strcmp("FFTBins",azColName[i]) != 0)
      printf("%s,", argv[i] ? argv[i] : "NULL");
    else
    {
      float *pFFTBins = (float*)argv[i];
      for (int j=0; j<128; j++)
      {
	printf("%f,", *pFFTBins++);
      }
      printf("\n");
      
    }
      
  }

  return 0;

}

static int callback2(void *NotUsed, int argc, char **argv, char **azColName){
  int i;

  for(i=0; i<argc; i++){
    
    //printf("%s = %s\n", azColName[i], argv[i] ? argv[i] : "NULL");

    float *pFFTBins = (float*)argv[i];
    for (int j=0; j<128; j++)
    {
      printf("%f, ", *pFFTBins++);
    }

  }
  printf("\n");
  return 0;
}

int main(int argc, char **argv){
  sqlite3 *db;
  char *zErrMsg = 0;
  int rc;
  sqlite3_int64 last_row_id;

  if( argc!=2 ){
    fprintf(stderr, "Usage: %s DATABASE\n", argv[0]);
    return(1);
  }
  rc = sqlite3_open(argv[1], &db);
  if( rc ){
    fprintf(stderr, "Can't open database: %s\n", sqlite3_errmsg(db));
    sqlite3_close(db);
    return(1);
  }

  rc = sqlite3_exec(db, "select * from spectrum_data where oml_sender_id=1", callback1, 0, &zErrMsg);
  if( rc!=SQLITE_OK ){
    fprintf(stderr, "SQL error: %s\n", zErrMsg);
    sqlite3_free(zErrMsg);
  }

  /*
  rc = sqlite3_exec(db, "select FFTBins from spectrum_data where rowid=9", callback2, 0, &zErrMsg);
  if( rc!=SQLITE_OK ){
    fprintf(stderr, "SQL error: %s\n", zErrMsg);
    sqlite3_free(zErrMsg);
  }
  */

  //fprintf(stdout, "Last row id: %lld\n", sqlite3_last_insert_rowid(db));

  sqlite3_close(db);
  return 0;
}
