defProperty('freq',  1500e6, "Starting rx frequency")
defProperty('dwell', 3, "Number of seconds at each frequency step")

defGroup('txnode', 'node2-2.grid.orbit-lab.org') { |n|
}

defGroup('rxnode', 'node1-1.grid.orbit-lab.org,node20-20.grid.orbit-lab.org') { |n|
}

onEvent(:ALL_UP) do |event|
  info "Give machines some time to warm up" 
  wait 4

  info "activate"
  allGroups.uhd.u0.activate                         # starts UHD daemon
  wait 3

  info "set tx parameters"
  group("txnode").uhd.u0.txfreq = property.freq     # set tx frequency (Hz)
  group("txnode").uhd.u0.txrate = "8e6"             # set tx sampling rate
  group("txnode").uhd.u0.txgain = "30"              # set tx gain (dB)
  group("txnode").uhd.u0.txampl = "0.7"             # set tx wavform amplitude
  #group("txnode").uhd.u0.txwavefreq = "1e6"
  group("txnode").uhd.u0.txwavetype = "CONST"       # set type of waveform to transmit = {CONST, SINE, RAMP}
  group("txnode").uhd.u0.transmit                   # start transmitting

  group("rxnode").uhd.u0.rxfreq = property.freq     # set rx frequency
  group("rxnode").uhd.u0.rxrate = "8e6"             # set rx sampling rate
  group("rxnode").uhd.u0.rxgain = "25"              # set rx gain
  group("rxnode").uhd.u0.numbins = "128"            # number of fft points
  group("rxnode").uhd.u0.avgwinlen = "32"           # set averaging window size for each fft bin across time.
  group("rxnode").uhd.u0.omlfile = "spectrum.grid"  # oml database file name to store fft data
  group("rxnode").uhd.u0.omlserver = "idb2:3003"    # oml server
  group("rxnode").uhd.u0.record                     # start recording

  (0..30).each { |i|                      # set up loop    
    offset = (rand()*4).to_f              # find next transmit frequency
    cf = property.freq + (offset*1e6)
    group("txnode").uhd.u0.txfreq = cf    # set new transmit frequency
    wait property.dwell                   # wait for a few seconds
  }


  allGroups.uhd.u0.stop                             # stop transmitting and stop recording
  allGroups.uhd.u0.deactivate                       # stop UHD daemon

  info "Finish it." 
  Experiment.done
end
